##############################
#=== setup mechanism for application framework ===#
##############################

##################
#=== define constants used ===#
##################

## input system bundle path ##
$inputSystemBundle = "inputengine"
## plugin bundle path ##
$pluginBundle = "plugin"
## physics update step time (second) ##
$simStepTime = 0.02
## path of current working directory ##
$resourcePath = "./res"
## path of file which setup the whole scene ##
$sceneFilePath = "env/athene.ses"
## net server port ##
$netPort = 4242

##############
#=== setup services ===#
##############

## pool for saving services ##
serverPool = get("_frame/Pool", "")

## simulation server ##
simServer = new("_oxygen/SimulationServer", "")
serverPool.save("_oxygen/SimulationServer", "")

simServer.setTimeStep($simStepTime)
simServer.setResourcePath($resourcePath)
simServer.setSceneFile($sceneFilePath)

## geometer server ##
geomServer = new("_oxygen/GeometryServer", "")
serverPool.save("_oxygen/GeometryServer", "")

## OpenGL server ##
openglServer = new("_graphx/OpenGLServer", "")
serverPool.save("_graphx/OpenGLServer", "")

matServer = new("_graphx/MaterialServer", "")
serverPool.save("_graphx/MaterialServer", "")

texServer = new("_graphx/TextureServer", "")
serverPool.save("_graphx/TextureServer", "")

renderServer = new("_graphx/RenderServer", "")
serverPool.save("_graphx/RenderServer", "")

openglServer.init()

## ODE server ##
odeServer = new("_physx/ODEServer", "")
serverPool.save("_physx/ODEServer", "")

## input server ##
importBundle($inputSystemBundle)

inputServer = new("_shell/InputServer", "")
serverPool.save("_shell/InputServer", "")

## render control node ##
simServer.initSimCtrlNode("_graphx/RenderCtrlNode", "", 0)

## input control node ##
simServer.initSimCtrlNode("_shell/InputCtrlNode", "", 0)

## net server ##
simServer.initSimCtrlNode("_oxygen/NetServer", "", 0)

## plugin ##
importBundle($pluginBundle)

sceneServer = get("_oxygen/SceneServer", "")
sceneServer.initSceneImporter("_plugin/SExpSceneImporter")

geomServer.initMeshImporter("_plugin/ObjImporter")

texServer.initImageServer("_plugin/DevILImageServer")

netServer = get("_oxygen/NetServer", "")
netServer.initNetSystem("_plugin/TCPNetSystem", "")
netServer.initHost($netPort)

## import material ##
run("material.rb")

importBundle("extern")